@@ -8,7 +8,7 @@ package Devel::MAT;
 use strict;
 use warnings;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 use Carp;
 use List::Util qw( first pairs );
@@ -17,6 +17,8 @@ use List::UtilsBy qw( sort_by );
 use Devel::MAT::Dumpfile;
 use Devel::MAT::Graph;
 
+use Devel::MAT::InternalTools;
+
 use Module::Pluggable
    sub_name => "_available_tools",
    search_path => [ "Devel::MAT::Tool" ],
@@ -29,6 +31,18 @@ XSLoader::load( __PACKAGE__, $VERSION );
 
 C<Devel::MAT> - Perl Memory Analysis Tool
 
+=head1 USER GUIDE
+
+B<NEW USERS:>
+
+If you are new to the C<Devel::MAT> set of tools, this is probably not the
+document you want to start with. If you are interested in using C<Devel::MAT>
+to help diagnose memory-related problems in a F<perl> program you instead want
+to read the user guide, at L<Devel::MAT::UserGuide>.
+
+If you are writing tooling modules to extend the abilities of C<Devel::MAT>
+then this may indeed by the document for you; read on...
+
 =head1 DESCRIPTION
 
 A C<Devel::MAT> instance loads a heapdump file, and provides a container to
@@ -187,6 +201,11 @@ Specifies the type of inrefs followed. By default all inrefs are followed.
 Passing C<strong> will follow only strong direct inrefs. Passing C<direct>
 will follow only direct inrefs.
 
+=item elide => BOOL
+
+If true, attempt to neaten up the output by skipping over C<REF()>-type SVs
+which occur a lot in perl data structures.
+
 =back
 
 =cut
@@ -222,6 +241,24 @@ sub inref_graph
    my @inrefs = $opts{strong} ? $sv->inrefs_strong :
                 $opts{direct} ? $sv->inrefs_direct :
                                 $sv->inrefs;
+
+   if( $opts{elide} ) {
+      @inrefs = map { sub {
+         return $_ unless $_->sv->type eq "REF" and
+                          $_->name eq "the referrant";
+
+         my $rv = $_->sv;
+         my @rvrefs = $opts{strong} ? $rv->inrefs_strong :
+                      $opts{direct} ? $rv->inrefs_direct :
+                                      $rv->inrefs;
+
+         # Add 'via RV' marker
+         return map {
+            Devel::MAT::SV::Reference( "(via RV) " . $_->name, $_->strength, $_->sv )
+         } @rvrefs;
+      }->() } @inrefs;
+   }
+
    foreach my $ref ( sort_by { $_->name } @inrefs ) {
       if( !defined $ref->sv ) {
          # e.g. "a value on the stack"
