@@ -1,15 +1,16 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2017 -- leonerd@leonerd.org.uk
 
 package Devel::MAT::Dumper;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
+use Cwd qw( abs_path );
 use File::Basename qw( basename );
 
 require XSLoader;
@@ -82,10 +83,22 @@ F<$0.pmat> if not supplied.
 
    $ perl -MDevel::MAT::Dumper=-file,foo.pmat ...
 
+In the special case that C<$0> is exactly the string C<-e> or C<-E>, the
+filename will be prefixed with C<perl> so as not to create files whose names
+begin with a leading hyphen, as this confuses some commandline parsers.
+
+   $ perl -MDevel::MAT::Dumper=-dump_at_END -E 'say "hello"'
+   hello
+   Dumping to perl-e.pmat because of END
+
 If the pattern contains C<NNN>, this will be replaced by a unique serial
 number per written file, starting from 0. This may be helpful in the case of
 C<DIE> or C<SIGQUIT> handlers, which could be invoked multiple times.
 
+The file name is converted to an absolute path immediately, so if the running
+program later calls C<chdir()>, it will still be generated in the directory
+the program started from rather than the one it happens to be in at the time.
+
 =head2 -max_string
 
 Sets the maximum length of string buffer to dump from PVs; defaults to 256 if
@@ -103,7 +116,10 @@ open filehandles.
 
 our $MAX_STRING = 256; # used by XS code
 
-my $dumpfile_name = basename( $0 ) . ".pmat";
+my $basename = basename( $0 );
+$basename = "perl$basename" if $basename =~ m/^-e$/i; # RT119164
+my $dumpfile_name = abs_path( $basename ) . ".pmat";
+
 my $dumpfh;
 my $next_serial = 0;
 
@@ -165,7 +181,7 @@ sub import
          };
       }
       elsif( $sym eq "-file" ) {
-         $dumpfile_name = shift;
+         $dumpfile_name = abs_path( shift );
       }
       elsif( $sym eq "-max_string" ) {
          $MAX_STRING = shift;
