@@ -7,10 +7,8 @@ package Devel::MAT::SV;
 
 use strict;
 use warnings;
-use feature qw( switch );
-no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -364,7 +362,7 @@ boolean true and false. They are
 
 package Devel::MAT::SV::Immortal;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 use constant immortal => 1;
 sub new {
    my $class = shift;
@@ -377,13 +375,13 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::UNDEF;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 sub desc { "UNDEF" }
 sub type { "UNDEF" }
 
 package Devel::MAT::SV::YES;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 sub desc { "YES" }
 sub type { "SCALAR" }
 
@@ -398,7 +396,7 @@ sub name {}
 
 package Devel::MAT::SV::NO;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 sub desc { "NO" }
 sub type { "SCALAR" }
 
@@ -413,7 +411,7 @@ sub name {}
 
 package Devel::MAT::SV::Unknown;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 0xff );
 
 sub desc { "UNKNOWN" }
@@ -422,7 +420,7 @@ sub _outrefs {}
 
 package Devel::MAT::SV::GLOB;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 1 );
 
 =head1 Devel::MAT::SV::GLOB
@@ -575,7 +573,7 @@ sub _outrefs
 
 package Devel::MAT::SV::SCALAR;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 2 );
 
 =head1 Devel::MAT::SV::SCALAR
@@ -729,7 +727,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REF;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 3 );
 
 =head1 Devel::MAT::SV::REF
@@ -806,7 +804,7 @@ sub _outrefs
 
 package Devel::MAT::SV::ARRAY;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 4 );
 
 =head1 Devel::MAT::SV::ARRAY
@@ -926,7 +924,7 @@ sub _outrefs
 package Devel::MAT::SV::PADLIST;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 use constant type => "PADLIST";
 
 =head1 Devel::MAT::SV::PADLIST
@@ -962,7 +960,7 @@ sub _outrefs
 package Devel::MAT::SV::PADNAMES;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 use constant type => "PADNAMES";
 
 =head1 Devel::MAT::SV::PADNAMES
@@ -1038,7 +1036,7 @@ sub _outrefs
 package Devel::MAT::SV::PAD;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 use constant type => "PAD";
 
 use List::Util qw( pairmap );
@@ -1099,7 +1097,7 @@ sub _outrefs
 
 package Devel::MAT::SV::HASH;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 5 );
 
 =head1 Devel::MAT::SV::HASH
@@ -1229,7 +1227,7 @@ sub _outrefs
 
 package Devel::MAT::SV::STASH;
 use base qw( Devel::MAT::SV::HASH );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 6 );
 
 =head1 Devel::MAT::SV::STASH
@@ -1349,7 +1347,7 @@ sub _outrefs
 
 package Devel::MAT::SV::CODE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 7 );
 
 use Carp;
@@ -1386,19 +1384,19 @@ sub load
    $self->{padnames} = [] if $df->{perlver} > ( ( 5 << 24 ) | ( 20 << 16 ) | 0xffff );
 
    while( my $type = $df->_read_u8 ) {
-      given( $type ) {
-         when( 1 ) { push @{ $self->{consts_at} }, $df->_read_ptr }
-         when( 2 ) { push @{ $self->{constix} }, $df->_read_uint }
-         when( 3 ) { push @{ $self->{gvs_at} }, $df->_read_ptr }
-         when( 4 ) { push @{ $self->{gvix} }, $df->_read_uint }
-         when( 5 ) { my $padix = $df->_read_uint;
-                     $self->{padnames}[$padix] = _load_padname( $df ); }
-         when( 6 ) { # ignore - used to be padsvs_at
-                     $df->_read_uint; $df->_read_uint; $df->_read_ptr; }
-         when( 7 ) { $self->_set_padnames_at( $df->_read_ptr ); }
-         when( 8 ) { my $depth = $df->_read_uint;
-                     $self->{pads_at}[$depth] = $df->_read_ptr; }
-         default   { die "TODO: unhandled CODEx type $type"; }
+      if   ( $type == 1 ) { push @{ $self->{consts_at} }, $df->_read_ptr }
+      elsif( $type == 2 ) { push @{ $self->{constix} }, $df->_read_uint }
+      elsif( $type == 3 ) { push @{ $self->{gvs_at} }, $df->_read_ptr }
+      elsif( $type == 4 ) { push @{ $self->{gvix} }, $df->_read_uint }
+      elsif( $type == 5 ) { my $padix = $df->_read_uint;
+                            $self->{padnames}[$padix] = _load_padname( $df ); }
+      elsif( $type == 6 ) { # ignore - used to be padsvs_at
+                            $df->_read_uint; $df->_read_uint; $df->_read_ptr; }
+      elsif( $type == 7 ) { $self->_set_padnames_at( $df->_read_ptr ); }
+      elsif( $type == 8 ) { my $depth = $df->_read_uint;
+                            $self->{pads_at}[$depth] = $df->_read_ptr; }
+      else {
+         die "TODO: unhandled CODEx type $type";
       }
    }
 }
@@ -1679,8 +1677,11 @@ sub padix_from_padname
    my $padnames = $self->{padnames};
 
    foreach my $padix ( 1 .. $#$padnames ) {
+      my $thisname;
+
       return $padix if defined $padnames->[$padix] and
-                       $padnames->[$padix]->name eq $padname;
+                       defined( $thisname = $padnames->[$padix]->name ) and
+                       $thisname eq $padname;
    }
 
    return undef;
@@ -1793,7 +1794,7 @@ sub _outrefs
 
 package Devel::MAT::SV::IO;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 8 );
 
 =head1 Devel::MAT::SV::IO
@@ -1850,7 +1851,7 @@ sub _outrefs
 
 package Devel::MAT::SV::LVALUE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 9 );
 
 sub load
@@ -1883,7 +1884,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REGEXP;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 10 );
 
 sub load {}
@@ -1894,7 +1895,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::FORMAT;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 11 );
 
 sub load {}
@@ -1905,7 +1906,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::INVLIST;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 __PACKAGE__->register_type( 12 );
 
 sub load {}
