@@ -10,6 +10,8 @@ use warnings;
 use base qw( Devel::MAT::Tool );
 use utf8;
 
+our $VERSION = '0.25';
+
 use Getopt::Long qw( GetOptionsFromArray );
 use List::Util qw( pairs );
 use List::UtilsBy qw( nsort_by );
@@ -42,9 +44,6 @@ my %STRENGTH_ORDER = (
    inferred => 4,
 );
 
-my $STRONG;
-my $DIRECT;
-
 my $next_id;
 my %id_for;
 my %seen;
@@ -142,6 +141,15 @@ ones will be included).
 
 Include both weak and indirect references in the output.
 
+=item --no-elide, -n
+
+Don't elide C<REF()>-type SVs from the output. By default these will be
+skipped over, leading to a shorter neater output by removing this
+usually-unnecessary noise.
+
+If this option is not given, elided reference SVs will be notated by adding
+C<(via RV)> to the reference description.
+
 =back
 
 =cut
@@ -157,11 +165,13 @@ sub run_cmd
 
    my $STRONG = 1;
    my $DIRECT = 1;
+   my $ELIDE  = 1;
 
    GetOptionsFromArray( \@_,
-      'depth|d=i' => \my $DEPTH,
-      'weak'      => sub { $STRONG = 0 },
-      'all'       => sub { $STRONG = 0; $DIRECT = 0 },
+      'depth|d=i'  => \my $DEPTH,
+      'weak'       => sub { $STRONG = 0 },
+      'all'        => sub { $STRONG = 0; $DIRECT = 0 },
+      'no-elide|n' => sub { $ELIDE = 0; },
    ) or return;
 
    my $addr = $_[0] // die "Need an SV addr\n";
@@ -176,6 +186,7 @@ sub run_cmd
       depth => $DEPTH,
       strong => $STRONG,
       direct => $DIRECT,
+      elide  => $ELIDE,
    ) );
 }
 
