@@ -7,10 +7,8 @@ package Devel::MAT::Tool::Reachability;
 
 use strict;
 use warnings;
-use feature qw( switch );
-no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 use constant FOR_UI => 1;
 
@@ -196,11 +194,11 @@ sub mark_reachable
          my @more_user;
          my @more_internal;
 
-         given( $sv->type ) {
-            when( "REF" )    { push @more_user, $sv->rv if $sv->rv }
-            when( "ARRAY" )  { push @more_user, $sv->elems; }
-            when( "HASH" )   { push @more_user, $sv->values; }
-            when( "GLOB" ) {
+         for( $sv->type ) {
+            if   ( $_ eq "REF" )    { push @more_user, $sv->rv if $sv->rv }
+            elsif( $_ eq "ARRAY" )  { push @more_user, $sv->elems; }
+            elsif( $_ eq "HASH" )   { push @more_user, $sv->values; }
+            elsif( $_ eq "GLOB" ) {
                my $gv = $sv;
                next if $gv->{tool_reachable}; # already on symbol table
 
@@ -208,7 +206,7 @@ sub mark_reachable
                # Hard to know if the GV is being used for GVSV, GVAV, GVHV or GVCV
                push @more_user, $gv->scalar, $gv->array, $gv->hash, $gv->code, $gv->egv, $gv->io, $gv->form;
             }
-            when( "CODE" ) {
+            elsif( $_ eq "CODE" ) {
                my $cv = $sv;
 
                my @more_padlist;
@@ -262,14 +260,14 @@ sub mark_reachable
                $_ and !$_->{tool_reachable} and
                   $_->{tool_reachable} = REACH_LEXICAL, push @user, $_ for @more_lexical;
             }
-            when( "LVALUE" ) {
+            elsif( $_ eq "LVALUE" ) {
                my $lv = $sv;
 
                push @more_internal, $lv->target if $lv->target;
             }
-            when([ "UNDEF", "SCALAR", "IO", "REGEXP", "FORMAT" ]) { } # ignore
+            elsif( $_ =~ m/^(?:UNDEF|SCALAR|IO|REGEXP|FORMAT)$/ ) { } # ignore
 
-            default { warn "Not sure what to do with user data item ".$sv->desc_addr."\n"; }
+            else { warn "Not sure what to do with user data item ".$sv->desc_addr."\n"; }
          }
 
          $_ and !$_->{tool_reachable} and !$_->immortal and
